@@ -104,8 +104,8 @@ p_line <- function(nbst, filei, serlab, title, type,
     p = p + stat_smooth(method=lm, se=FALSE)
 
   # Ecriture des labels
-  p <- p + theme(panel.background=element_rect(fill="white", colour="grey30"),
-                 panel.grid.major=element_line(colour="grey30"),
+  p <- p + theme(panel.background=element_rect(fill="white", colour="black", linewidth = 2),
+                 panel.grid.major=element_line(colour="black"),
                  panel.grid.minor=element_line(colour=NA))
 
   p <- p +
